Parse string into tree of tokens. Fully customizable process of parsing. 

General architecture
--------------------
I intentionally use Dart native objects for result, so the whole chain of parsers could 
be injected by some extra custom step at runtime.

Basic tokenize
--------------
Split string into words, numbers and other character tokens.

```dart
import 'package:string2tree/string2tree.dart' as s2t;
...
List r = new s2t.Parser("this is a test").result;
```
List r contains 7 Map objects with keys: start, end, type.
```
|this| |is| |a| |test|
|----|-|--|-|-|-|----|
 0123 4 56 7 8 9 0123 -> indexes in source string
(0,3,65), (4,4,32), (5,6,65), (7,7,32), (8,8,65), (9,9,32), (10,13,65)
```

Specific processors
-------------------
- apostropheQuote - creates a group token for tokens between apostrophes, including them 
```
String s = "this is 'a special test' of '' single 'quote'";
List r = new s2t.Parser(s).apostropheQuote(-1).result;
r contains 13 tokens, where 5th, 9th and 13th have children
|this| |is| |'|a| |special| |test|'| |of| |'|'| |single| |'|quote|'|
|----|-|--|-|----------------------|-|--|-|---|-|------|-|---------|
            |-|-|-|-------|-|----|-|      |-|-|          |-|-----|-|
```
- brackets - creates a group token for tokens between brackets, including them
- removeSpaces - removes spaces from whole tree

Parsing mathematical expression
-------------------------------
```
String s = " a *(b + d) + 3(c-4)";
will be parsed into the tree:
    (a)-(*)-()-(+)-(3)-()
            |          |
     ---------      ---------
    (b)-(+)-(d)    (c)-(-)-(4)
```
